@@ -3,7 +3,7 @@
  rubber.js -- a base class for drag/rubber-band selection in gbrowse
 
  Sheldon McKay <mckays@cshl.edu>
- $Id: rubber.js 22706 2010-02-17 09:53:20Z sheldon_mckay $
+ $Id: rubber.js 23311 2010-06-03 21:11:00Z lstein $
 
 */
 
@@ -35,7 +35,7 @@ SelectArea.prototype.replaceImage = function(image) {
   image.setAttribute('name',name);
 
   // escape backslashes that may appear in the src attribute
-  src = src.replace(/\\/g,"\\\\");
+  src = escape(src.replace(/\\/g,"\\\\"));
 
   YAHOO.util.Dom.setStyle(image,'background', 'url('+src+') top left no-repeat');
   YAHOO.util.Dom.setStyle(image,'width', width+'px');
