@@ -7,7 +7,7 @@ package Bio::Graphics::Browser2::TrackDumper;
 #
 ###################################################################
 
-# $Id: TrackDumper.pm 23353 2010-06-10 20:09:08Z lstein $
+# $Id: TrackDumper.pm 23501 2010-06-29 19:45:54Z lstein $
 
 # Simple track dumper, suitable for a lightweight replacement to DAS.
 # Call this way:
@@ -137,6 +137,18 @@ sub dump_sam {
     my $header = $db->header;
 
     print $header->text;
+
+    my $build   = $self->data_source->build_id;
+    my $species = $self->data_source->species;
+    my @fields;
+    push @fields,"SP:$species" if $species;
+    push @fields,"AS:$build"   if $build;
+
+    for my $seqid ($db->seq_ids) {
+	my $length = $db->length($seqid) or next;
+	print "\@SQ\tSN:$seqid\tLN:$length\t",join("\t",@fields),"\n";
+    }
+
     print "\@CO\t$key\n";
     print "\@CO\tGenerated by GBrowse from ",$self->origin($label),"\n";
     print "\@CO\tSequence-region ",$segment->seq_id,':',$segment->start,'..',$segment->end,"\n" if $segment;
@@ -204,6 +216,14 @@ sub dump_bigwig {
 
     my $last_type = '';
     my $last_name = '';
+    
+    my $build   = $self->data_source->build_id  || 'unknown';
+    my $species = $self->data_source->species;
+    my $taxid   = $self->data_source->taxon_id;
+    my $description = "Generated by GBrowse from $origin";
+    $description   .= "; species=$species" if $species;
+    $description   .= "; taxid=$taxid"     if $taxid;
+    $build         .= "; build=$build"     if $build;
 
     while (my $f = $iterator->next_seq) {
 	my $type = $f->type;
@@ -212,7 +232,7 @@ sub dump_bigwig {
 	if ($type ne $last_type or $name ne $last_name) {
 	    print "\n" if $last_type or $last_name;
 	    $name ||= $type;
-	    print qq(track type=wiggle_0 name="$key ($name)" description="Generated by GBrowse from $origin"\n);
+	    print qq(track type=wiggle_0 name="$key ($name)" description="$description"\n);
 	    $last_type = $type;
 	}
 
@@ -256,9 +276,22 @@ sub print_gff3_header {
     my $segment = shift;
 
     my $date = localtime;
+    my $source = $self->data_source;
+    my $build  = $self->data_source->build_id  || 'unknown';
+    my $name   = $self->data_source->species;
+    my $taxid  = $self->data_source->taxon_id;
+
+    my $ncbi   = 'http://www.ncbi.nlm.nih.gov/Taxonomy/Browser/wwwtax.cgi';
+
+    my $species =  $taxid ? "$ncbi?id=$taxid"
+	          :$name  ? "$ncbi?name=$name"
+		  :undef;
+
     print "##gff-version 3\n";
     print "##date $date\n";
     print "##source gbrowse gbgff gff3 dumper\n";
+    print "##species $species\n" if $species;
+    print "##genome-build $build\n";
     if ($segment) {
 	print "##sequence-region ",$segment->seq_id,':',$segment->start,'..',$segment->end,"\n";
     }
@@ -696,6 +729,7 @@ sub get_scan {
 	next unless    $config->fallback_setting($l => 'discoverable');
 	next if        $config->code_setting($l=>'global feature');
 	my $key      = $config->code_setting($l => 'key');
+	my $category = $config->code_setting($l => 'category');
 	my $citation = $config->code_setting($l => 'citation');
 	my $subtracks = $config->subtrack_scan_list($l);
 	$result .=  <<END;
@@ -705,6 +739,7 @@ END
     ;
     $result .=  "select   = @$subtracks\n" if $subtracks;
     $result .=  "citation = $citation\n"   if $citation;
+    $result .=  "category = $category\n"   if $category;
     $result .=  "\n";
     }
 return $result;
