@@ -165,6 +165,10 @@ END
 
    HELP_FORMAT => 'Help with File Format',
 
+   HELP_FORMAT_UPLOAD => 'Help with uploading custom tracks',
+
+   HELP_FORMAT_IMPORT => 'Help with importing custom tracks',
+
    CANCEL   => 'Cancel',
 
    ABOUT    => 'About...',
@@ -217,6 +221,10 @@ END
 
    DATA_SOURCE => 'Data Source',
 
+   UPLOADED_TRACKS => 'Uploaded Tracks',
+
+   IMPORTED_TRACKS => 'Imported Tracks',
+
    UPLOAD_TRACKS=>'Add custom tracks',
 
    USERDATA_TABLE=>'Upload and share tracks',
